@@ -83,7 +83,11 @@ Optimizer = R6Class("Optimizer",
     #' @param inst ([OptimInstance]).
     #' @return [data.table::data.table].
     optimize = function(inst) {
-      optimize_default(inst, self, private)
+      inst$.__enclos_env__$private$.context = ContextOptimization$new(instance = inst, optimizer = self)
+      call_back("on_optimization_begin", inst$callbacks, get_private(inst)$.context)
+      result = optimize_default(inst, self, private)
+      call_back("on_optimization_end", inst$callbacks, get_private(inst)$.context)
+      result
     }
   ),
 
